package de.uni_kassel.pmss10.mancala.gui;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.util.HashMap;
import java.util.Map;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;

public class GameScreen extends JFrame
{
   private Map<Integer, JButton> pitButtonMap = new HashMap<Integer, JButton>();
   private JLabel firstPlayerNameLabel;
   private JButton firstPlayerKalahButton;
   private JButton quitButton;
   private JLabel secondPlayerNameLabel;
   private JButton secondPlayerKalahButton;
   
   public GameScreen()
   {
      // Create the background
      JPanel background = new BackgroundPanel("images/MancalaBackground.jpg");
      background.setBorder(BorderFactory.createEmptyBorder(20, 20, 20, 20));
      background.setLayout(new GridBagLayout());
      
      // Add the background
      getContentPane().add(background, BorderLayout.CENTER);
      
      // Create the content
      createContent(background);
      
      // Set size 
      pack();
      
      // Center frame
      setLocationRelativeTo(null);
      
      // Close on exit
      setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
      
      // Show it
      setVisible(true);
   }
   
   private void createContent(JPanel parent)
   {
      // Create 3 columns:
      //    - Left column is holding first playername, firstplayer kalah and the quit button
      //    - Middle column is holding the pits 1-12
      //    - Right column is holding second playername and secondplayer kalah 
      GridBagConstraints c = new GridBagConstraints();
      c.fill = GridBagConstraints.VERTICAL;
      c.weighty = 1;
      
      // Create the left column
      JPanel leftColumn = new JPanel();
      leftColumn.setOpaque(false);
      leftColumn.setLayout(new GridBagLayout());
      GridBagConstraints leftC = new GridBagConstraints();
      leftC.anchor = GridBagConstraints.FIRST_LINE_START;
      
      firstPlayerNameLabel = new JLabel("Alice: 10");
      leftColumn.add(firstPlayerNameLabel,leftC);
      
      secondPlayerKalahButton = new JButton();
      secondPlayerKalahButton.setPreferredSize(new Dimension(50,120));
      leftC.anchor = GridBagConstraints.LINE_END;
      leftC.weighty = 1;
      leftC.gridy = 1;
      leftC.insets = new Insets(120, 0, 0, 0);
      leftColumn.add(secondPlayerKalahButton, leftC);
      
      quitButton = new JButton("Quit");
      leftC.anchor = GridBagConstraints.FIRST_LINE_START;
      leftC.gridy = 2;
      leftColumn.add(quitButton, leftC);
      
      parent.add(leftColumn, c);
      
      // Create the middle column
      JPanel middleColumn = new JPanel();
      middleColumn.setOpaque(false);
      middleColumn.setLayout(new BoxLayout(middleColumn, BoxLayout.PAGE_AXIS));
      middleColumn.setBorder(BorderFactory.createEmptyBorder(50, 0, 50, 0));
      
      JPanel upperPitButtonPanel = new JPanel(new FlowLayout(FlowLayout.CENTER, 10,0));
      upperPitButtonPanel.setOpaque(false);
      for(int i=12; i >=7; i--)
      {
         JButton pitButton = new JButton();
         pitButton.setPreferredSize(new Dimension(50,50));
         pitButtonMap.put(i, pitButton);

         upperPitButtonPanel.add(pitButton);
      }
      
      middleColumn.add(upperPitButtonPanel);
      middleColumn.add(Box.createVerticalStrut(200));
      
      JPanel lowerButtonPanel = new JPanel(new FlowLayout(FlowLayout.CENTER, 10, 0));
      lowerButtonPanel.setOpaque(false);
      for(int i=1; i <=6; i++)
      {
         JButton pitButton = new JButton();
         pitButton.setPreferredSize(new Dimension(50,50));
         pitButtonMap.put(i, pitButton);

         lowerButtonPanel.add(pitButton);
      }
      middleColumn.add(lowerButtonPanel);
      
      c.gridx = 1;
      parent.add(middleColumn, c);
      
      // Create the right panel
      JPanel rightColumn = new JPanel();
      rightColumn.setOpaque(false);
      rightColumn.setOpaque(false);
      rightColumn.setLayout(new GridBagLayout());
      rightColumn.setBackground(new Color(255,0,0));
      secondPlayerNameLabel = new JLabel("Bob: 2");
      secondPlayerNameLabel.setAlignmentY(0);
      
      
      GridBagConstraints rightC = new GridBagConstraints();
      rightC.anchor = GridBagConstraints.FIRST_LINE_END;
      rightColumn.add(secondPlayerNameLabel,rightC);
      
      firstPlayerKalahButton = new JButton();
      firstPlayerKalahButton.setPreferredSize(new Dimension(50,120));

      rightC.weighty = 1;
      rightC.gridy = 1;
      rightC.insets = new Insets(120, 0, 0, 0);
      rightC.anchor = GridBagConstraints.FIRST_LINE_START;
      rightColumn.add(firstPlayerKalahButton, rightC);
      
      c.gridx = 3;
      parent.add(rightColumn, c);
   }
   
   public JButton getPitButton(int pitNr)
   {
      return pitButtonMap.get(pitNr);
   }
   
   public JLabel getFirstPlayerNameLabel()
   {
      return firstPlayerNameLabel;
   }
   
   public JLabel getSecondPlayerNameLabel()
   {
      return secondPlayerNameLabel;
   }
   
   public JButton getFirstPlayerKalahButton()
   {
      return firstPlayerKalahButton;
   }
   
   public JButton getSecondPlayerKalahButton()
   {
      return secondPlayerKalahButton;
   }
   
   public JButton getQuitButton()
   {
      return quitButton;
   }
}
